@@ -621,7 +621,7 @@ def get_status_info(delivery_order):
         description_dic = get_delivery_order_status_description_dic()
         description = description_dic[delivery_order['status']]
 
-    elif DeliveryOrderStatusType.Delivered.value == DeliveryOrderStatusType.Delivered.value:
+    elif delivery_order['status'] == DeliveryOrderStatusType.Delivered.value:
         events_info = filter(
             lambda x: x['status'] == DeliveryOrderStatusType.Delivered.value,
             delivery_order['events_info']
@@ -948,6 +948,8 @@ class DeliveryOrderClient(EntityClientBase):
     def update_documents(self, id, params):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_update-documents".format(id), params)
 
+    def assignment_courier(self, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "_assignment-courier", params)
 
 class DeliveryOrderMessagingClient(EntityClientBase):
     entity_endpoint_base_url = '/delivery/delivery-orders-messaging/'
